@@ -7,6 +7,10 @@
 *
 **********/
 
+#if defined(HAVE_CONFIG_H)
+#include "config.h"
+#endif
+
 //BibleTime includes
 #include "cswordmoduleinfo.h"
 #include "cswordbackend.h"
@@ -32,7 +36,7 @@
 #include <tqvariant.h>
 #include <tqfileinfo.h>
 
-//KDE includes
+//TDE includes
 #include <tdelocale.h>
 #include <tdeglobal.h>
 #include <kstandarddirs.h>
