@@ -28,7 +28,7 @@ class KProgressDialog;
  * @author The BibleTime team <info@bibletime.info>
 */
 class CModuleIndexDialog : public TQObject {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	/** Get the singleton instance.
