@@ -48,7 +48,7 @@
 #include <tqdir.h>
 
 //TDE includes
-#include <kapp.h>
+#include <tdeapplication.h>
 #include <tdelocale.h>
 #include <tdeglobal.h>
 #include <kstandarddirs.h>
@@ -57,7 +57,6 @@
 #include <tdehtmlview.h>
 #include <kiconloader.h>
 #include <ktabctl.h>
-#include <kapp.h>
 #include <tdelistbox.h>
 #include <kkeydialog.h>
 #include <tdeaction.h>
