@@ -26,7 +26,7 @@
 //TQt includes
 #include <tqsplitter.h>
 
-//KDE includes
+//TDE includes
 #include <tdeaction.h>
 #include <tdelocale.h>
 #include <tdeversion.h>
@@ -65,7 +65,7 @@ void CBookReadWindow::initActions() {
 					   i18n("Toggle tree view"),
 					   CResMgr::displaywindows::bookWindow::toggleTree::icon,
 					   CResMgr::displaywindows::bookWindow::toggleTree::accel,
-					   TQT_TQOBJECT(this), TQT_SLOT(treeToggled()),
+					   this, TQ_SLOT(treeToggled()),
 					   actionCollection(), "toggleTree");
 
 	CBTConfig::setupAccelSettings(CBTConfig::bookWindow, actionCollection());
@@ -92,12 +92,12 @@ void CBookReadWindow::insertKeyboardActions( TDEActionCollection* const a ) {
 void CBookReadWindow::initConnections() {
 	CLexiconReadWindow::initConnections();
 
-	connect(m_treeChooser, TQT_SIGNAL(keyChanged(CSwordKey*)),
-			TQT_TQOBJECT(this), TQT_SLOT(lookup(CSwordKey*)));
-	connect(m_treeChooser, TQT_SIGNAL(keyChanged(CSwordKey*)),
-			keyChooser(), TQT_SLOT(updateKey(CSwordKey*)));
-	connect(keyChooser(), TQT_SIGNAL(keyChanged(CSwordKey*)),
-			m_treeChooser, TQT_SLOT(updateKey(CSwordKey*)));
+	connect(m_treeChooser, TQ_SIGNAL(keyChanged(CSwordKey*)),
+			this, TQ_SLOT(lookup(CSwordKey*)));
+	connect(m_treeChooser, TQ_SIGNAL(keyChanged(CSwordKey*)),
+			keyChooser(), TQ_SLOT(updateKey(CSwordKey*)));
+	connect(keyChooser(), TQ_SIGNAL(keyChanged(CSwordKey*)),
+			m_treeChooser, TQ_SLOT(updateKey(CSwordKey*)));
 }
 
 /** Init the view */
