@@ -19,7 +19,7 @@
 
 //TQt includes
 
-//KDE includes
+//TDE includes
 #include <tdeaction.h>
 #include <tdelocale.h>
 
@@ -48,10 +48,10 @@ void CHTMLWriteWindow::initView() {
 void CHTMLWriteWindow::initConnections() {
 	CWriteWindow::initConnections();
 
-	connect(keyChooser(), TQT_SIGNAL(keyChanged(CSwordKey*)),
-			TQT_TQOBJECT(this), TQT_SLOT(lookup(CSwordKey*)));
-	connect(displayWidget()->connectionsProxy(), TQT_SIGNAL(textChanged()),
-			TQT_TQOBJECT(this), TQT_SLOT(textChanged()) );
+	connect(keyChooser(), TQ_SIGNAL(keyChanged(CSwordKey*)),
+			this, TQ_SLOT(lookup(CSwordKey*)));
+	connect(displayWidget()->connectionsProxy(), TQ_SIGNAL(textChanged()),
+			this, TQ_SLOT(textChanged()) );
 };
 
 void CHTMLWriteWindow::initToolbars() {
@@ -68,7 +68,7 @@ void CHTMLWriteWindow::initToolbars() {
 	m_actions.saveText = new TDEAction( i18n("Save text"),
 									  CResMgr::displaywindows::writeWindow::saveText::icon,
 									  CResMgr::displaywindows::writeWindow::saveText::accel,
-									  TQT_TQOBJECT(this), TQT_SLOT( saveCurrentText()  ),
+									  this, TQ_SLOT( saveCurrentText()  ),
 									  actionCollection(),
 									  CResMgr::displaywindows::writeWindow::saveText::actionName
 									);
@@ -78,7 +78,7 @@ void CHTMLWriteWindow::initToolbars() {
 	m_actions.deleteEntry = new TDEAction(i18n("Delete current entry"),
 										CResMgr::displaywindows::writeWindow::deleteEntry::icon,
 										CResMgr::displaywindows::writeWindow::deleteEntry::accel,
-										TQT_TQOBJECT(this), TQT_SLOT(deleteEntry()),
+										this, TQ_SLOT(deleteEntry()),
 										actionCollection(),
 										CResMgr::displaywindows::writeWindow::deleteEntry::actionName
 									   );
@@ -88,7 +88,7 @@ void CHTMLWriteWindow::initToolbars() {
 	m_actions.restoreText = new TDEAction(i18n("Restore original text"),
 										CResMgr::displaywindows::writeWindow::restoreText::icon,
 										CResMgr::displaywindows::writeWindow::restoreText::accel,
-										TQT_TQOBJECT(this), TQT_SLOT(restoreText()), actionCollection(),
+										this, TQ_SLOT(restoreText()), actionCollection(),
 										CResMgr::displaywindows::writeWindow::restoreText::actionName
 									   );
 	m_actions.restoreText->setToolTip( CResMgr::displaywindows::writeWindow::restoreText::tooltip );
