@@ -24,7 +24,7 @@ class TDEAction;
   * @author The BibleTime team
   */
 class CHTMLWriteWindow : public CPlainWriteWindow  {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	CHTMLWriteWindow(ListCSwordModuleInfo modules, CMDIArea* parent, const char *name = 0);
