@@ -20,7 +20,7 @@
 //TQt includes
 #include <tqregexp.h>
 
-//KDE includes
+//TDE includes
 #include <tdeaction.h>
 #include <tdeaccel.h>
 #include <tdelocale.h>
@@ -65,7 +65,7 @@ void CPlainWriteWindow::initToolbars() {
 	m_actions.saveText = new TDEAction(i18n("Save text"),
 									 CResMgr::displaywindows::writeWindow::saveText::icon,
 									 CResMgr::displaywindows::writeWindow::saveText::accel,
-									 TQT_TQOBJECT(this), TQT_SLOT(saveCurrentText()),
+									 this, TQ_SLOT(saveCurrentText()),
 									 actionCollection(),
 									 CResMgr::displaywindows::writeWindow::saveText::actionName
 									);
@@ -76,7 +76,7 @@ void CPlainWriteWindow::initToolbars() {
 	m_actions.deleteEntry = new TDEAction(i18n("Delete current entry"),
 										CResMgr::displaywindows::writeWindow::deleteEntry::icon,
 										CResMgr::displaywindows::writeWindow::deleteEntry::accel,
-										TQT_TQOBJECT(this), TQT_SLOT(deleteEntry()),
+										this, TQ_SLOT(deleteEntry()),
 										actionCollection(),
 										CResMgr::displaywindows::writeWindow::deleteEntry::actionName
 									   );
@@ -87,7 +87,7 @@ void CPlainWriteWindow::initToolbars() {
 	m_actions.restoreText = new TDEAction(i18n("Restore original text"),
 										CResMgr::displaywindows::writeWindow::restoreText::icon,
 										CResMgr::displaywindows::writeWindow::restoreText::accel,
-										TQT_TQOBJECT(this), TQT_SLOT(restoreText()),
+										this, TQ_SLOT(restoreText()),
 										actionCollection(),
 										CResMgr::displaywindows::writeWindow::restoreText::actionName
 									   );
@@ -97,11 +97,11 @@ void CPlainWriteWindow::initToolbars() {
 
 void CPlainWriteWindow::initConnections() {
 	CWriteWindow::initConnections();
-	connect(keyChooser(), TQT_SIGNAL(keyChanged(CSwordKey*)),
-			TQT_TQOBJECT(this), TQT_SLOT(lookup(CSwordKey*)));
+	connect(keyChooser(), TQ_SIGNAL(keyChanged(CSwordKey*)),
+			this, TQ_SLOT(lookup(CSwordKey*)));
 
-	connect(displayWidget()->connectionsProxy(), TQT_SIGNAL(textChanged()),
-			TQT_TQOBJECT(this), TQT_SLOT(textChanged()) );
+	connect(displayWidget()->connectionsProxy(), TQ_SIGNAL(textChanged()),
+			this, TQ_SLOT(textChanged()) );
 }
 
 void CPlainWriteWindow::storeProfileSettings( CProfileWindow* profileWindow ) {
