@@ -29,7 +29,7 @@ class TDEPopupMenu;
   */
 
 class CReadWindow : public CDisplayWindow  {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	//  static void insertKeyboardActions( TDEAccel* const a );
