@@ -30,7 +30,7 @@ class TQHBoxLayout;
   * @author The BibleTime team
   */
 class CLexiconKeyChooser : public CKeyChooser  {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	/**
