@@ -28,7 +28,7 @@
   * @author The BibleTime team
   */
 class CScrollerWidgetSet : public TQWidget {
-	Q_OBJECT
+	TQ_OBJECT
   
 public:
 	/**
